==> gimp-1.3.12.tar.bz2: gimp-1.3.12/libgimpwidgets/gimpwidgetsmarshal.h <==

#ifndef ___gimp_widgets_marshal_MARSHAL_H__
#define ___gimp_widgets_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:INT (./gimpwidgetsmarshal.list:1) */
#define _gimp_widgets_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
#define _gimp_widgets_marshal_NONE__INT	_gimp_widgets_marshal_VOID__INT

/* NONE:INT,INT (./gimpwidgetsmarshal.list:2) */
extern void _gimp_widgets_marshal_VOID__INT_INT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
#define _gimp_widgets_marshal_NONE__INT_INT	_gimp_widgets_marshal_VOID__INT_INT

/* NONE:POINTER,POINTER (./gimpwidgetsmarshal.list:3) */
extern void _gimp_widgets_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
#define _gimp_widgets_marshal_NONE__POINTER_POINTER	_gimp_widgets_marshal_VOID__POINTER_POINTER

G_END_DECLS

#endif /* ___gimp_widgets_marshal_MARSHAL_H__ */

==> gimp-1.3.23.tar.bz2: gimp-1.3.23/libgimpwidgets/gimpwidgetsmarshal.h <==

#ifndef ___gimp_widgets_marshal_MARSHAL_H__
#define ___gimp_widgets_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT (./gimpwidgetsmarshal.list:25) */
#define _gimp_widgets_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,INT (./gimpwidgetsmarshal.list:26) */
extern void _gimp_widgets_marshal_VOID__INT_INT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:OBJECT (./gimpwidgetsmarshal.list:27) */
#define _gimp_widgets_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,INT (./gimpwidgetsmarshal.list:28) */
extern void _gimp_widgets_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:POINTER,POINTER (./gimpwidgetsmarshal.list:29) */
extern void _gimp_widgets_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

G_END_DECLS

#endif /* ___gimp_widgets_marshal_MARSHAL_H__ */
